==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/Shield/DescribeProtection.pm <==

package Paws::Shield::DescribeProtection;
  use Moose;
  has ProtectionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeProtection');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Shield::DescribeProtectionResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Shield::DescribeProtection - Arguments for method DescribeProtection on Paws::Shield

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeProtection on the 
AWS Shield service. Use the attributes of this class
as arguments to method DescribeProtection.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeProtection.

As an example:

  $service_obj->DescribeProtection(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ProtectionId => Str

The unique identifier (ID) for the Protection object that is described.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeProtection in L<Paws::Shield>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/Shield/DescribeProtection.pm <==

package Paws::Shield::DescribeProtection;
  use Moose;
  has ProtectionId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeProtection');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Shield::DescribeProtectionResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Shield::DescribeProtection - Arguments for method DescribeProtection on L<Paws::Shield>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeProtection on the
L<AWS Shield|Paws::Shield> service. Use the attributes of this class
as arguments to method DescribeProtection.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeProtection.

=head1 SYNOPSIS

    my $shield = Paws->service('Shield');
    my $DescribeProtectionResponse = $shield->DescribeProtection(
      ProtectionId => 'MyProtectionId',

    );

    # Results:
    my $Protection = $DescribeProtectionResponse->Protection;

    # Returns a L<Paws::Shield::DescribeProtectionResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/shield/DescribeProtection>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ProtectionId => Str

The unique identifier (ID) for the Protection object that is described.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeProtection in L<Paws::Shield>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
